package protocolP2P;
import java.util.HashMap;
import java.util.Map;

/** HashAlgorithm enum.
 * @author	Louis Royer
 * @author	Flavien Haas
 * @author	JS Auge
 * @version	1.0
 */
public enum HashAlgorithm {
	SHA512("SHA-512"),
	MD5("MD5");
	
	private String name;
	/* To be able to convert name to enum */
	private static final Map<Byte, HashAlgorithm> BY_CODE = new HashMap<>();
	/* Initialization of HashMap */
	static {
		for (HashAlgorithm h: values()) {
			assert !BY_CODE.containsKey(Byte.valueOf(h.name)) : "Duplicate in " + HashAlgorithm.class.getCanonicalName();
			BY_CODE.put(Byte.valueOf(h.name), h);
		}
	}

	HashAlgorithm(String name) {
		this.name = name;
	}

	public String getName() {
		return name;
	}

	/** Gives enum from name.
	 * @param name	name of the hash
	 * @return	enum element
	 * @throws	InterlanError
	 */
	protected static HashAlgorithm fromName(String name) throws InternalError {
		HashAlgorithm h = BY_CODE.get(Byte.valueOf(name));
		if (h == null) {
			throw new InternalError();
		}
		return h;
	}
	
}


